@@ -51,21 +51,21 @@ pub struct Manifest {
     pub webpack_config: Option<String>,
     pub build: Option<Builder>,
     pub private: Option<bool>,
-    // TODO: maybe one day, serde toml support will allow us to serialize sites
-    // as a TOML inline table (this would prevent confusion with environments too!)
-    pub site: Option<Site>,
     pub dev: Option<Dev>,
-    #[serde(alias = "kv-namespaces")]
-    pub kv_namespaces: Option<Vec<ConfigKvNamespace>>,
     pub triggers: Option<Triggers>,
-    pub durable_objects: Option<DurableObjects>,
     pub migrations: Option<Vec<MigrationConfig>>,
     #[serde(default, with = "string_empty_as_none")]
     pub usage_model: Option<UsageModel>,
     pub compatibility_date: Option<String>,
     #[serde(default)]
     pub compatibility_flags: Vec<String>,
+    pub durable_objects: Option<DurableObjects>,
     pub env: Option<HashMap<String, Environment>>,
+    #[serde(alias = "kv-namespaces")]
+    pub kv_namespaces: Option<Vec<ConfigKvNamespace>>,
+    // TODO: maybe one day, serde toml support will allow us to serialize sites
+    // as a TOML inline table (this would prevent confusion with environments too!)
+    pub site: Option<Site>,
     pub vars: Option<HashMap<String, String>>,
     pub text_blobs: Option<HashMap<String, PathBuf>>,
     pub wasm_modules: Option<HashMap<String, PathBuf>>,
@@ -94,13 +94,6 @@ impl Manifest {
 
         check_for_duplicate_names(&manifest)?;
 
-        if manifest.compatibility_date.is_none() {
-            StdOut::warn(&format!(
-                "Your configuration file is missing compatibility_date, so a distant past date is assumed. To get the latest possibly-breaking bug fixes, add this line to your wrangler.toml:\n\n    compatibility_date = \"{}\"\n",
-                Utc::now().format("%F")));
-            StdOut::warn("For more information about compatibility dates, see: https://developers.cloudflare.com/workers/platform/compatibility-dates");
-        }
-
         Ok(manifest)
     }
 
@@ -451,6 +444,25 @@ impl Manifest {
         }
     }
 
+    pub fn warn_about_compatibility_date(&self) {
+        if self.compatibility_date.is_some() {
+            return;
+        }
+        let current_date = Utc::now().format("%F");
+        let message = &format!(
+            r#"
+    Your configuration file is missing compatibility_date, so a past date is assumed.
+    To get the latest possibly-breaking bug fixes, add this line to your wrangler.toml:
+
+        compatibility_date = "{}"
+
+    For more information, see: https://developers.cloudflare.com/workers/platform/compatibility-dates
+        "#,
+            current_date
+        );
+        StdOut::warn(message);
+    }
+
     fn warn_on_account_info(&self) {
         let account_id_env = env::var("CF_ACCOUNT_ID").is_ok();
         let zone_id_env = env::var("CF_ZONE_ID").is_ok();
@@ -763,8 +775,15 @@ mod tests {
     #[test]
     fn serialize() {
         let manifest = Manifest {
+            durable_objects: Some(Default::default()),
+            kv_namespaces: Some(vec![ConfigKvNamespace {
+                binding: "FOO".to_string(),
+                id: Some("123".to_string()),
+                preview_id: None,
+            }]),
+            site: Some(Default::default()),
             vars: Some(
-                vec![(String::from("FOO"), String::from("some value"))]
+                vec![("FOO".to_string(), "some value".to_string())]
                     .into_iter()
                     .collect(),
             ),
