@@ -7,7 +7,9 @@ pub use manifest::AssetManifest;
 pub use sync::sync;
 
 use std::collections::HashSet;
+use std::error::Error;
 use std::ffi::OsString;
+use std::fmt;
 use std::fs;
 use std::hash::Hasher;
 use std::path::Path;
@@ -61,6 +63,17 @@ pub fn add_namespace(user: &GlobalUser, target: &mut Target, preview: bool) -> R
     Ok(site_namespace)
 }
 
+#[derive(Debug, Clone)]
+pub struct NotADirectoryError;
+
+impl fmt::Display for NotADirectoryError {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        write!(f, "Not a directory. Check your configuration file; the `bucket` attribute for [site] should point to a directory.")
+    }
+}
+
+impl Error for NotADirectoryError {}
+
 // Returns the hashed key and value pair for all files in a directory.
 pub fn directory_keys_values(
     target: &Target,
@@ -120,8 +133,7 @@ pub fn directory_keys_values(
         }
         Ok(_file_type) => {
             // any other file types (files, symlinks)
-            // TODO: return an error type here, like NotADirectoryError
-            Err(anyhow!("Check your configuration file; the `bucket` attribute for [site] should point to a directory."))
+            Err(anyhow::Error::new(NotADirectoryError))
         }
         Err(e) => Err(anyhow!(e)),
     }
